@@ -1,5 +1,5 @@
 /*
- * gpe-aerial (c) 2003, 2004 Florian Boor <florian.boor@kernelconcepts.de>
+ * gpe-aerial (c) 2003 - 2005 Florian Boor <florian.boor@kernelconcepts.de>
  *
  * Basic applet skeleton taken from gpe-bluetooth (see below)
  *
@@ -60,13 +60,22 @@
 static GThread *scan_thread;
 
 struct gpe_icon my_icons[] = {
-	{"scan-on", PREFIX "/share/pixmaps/scan-on-16.png"},
-	{"scan-off", PREFIX "/share/pixmaps/scan-off-16.png"},
+	{"scan-on", PREFIX "/share/pixmaps/scan-on.png"},
+	{"scan-off", PREFIX "/share/pixmaps/scan-off.png"},
 	{"network", PREFIX "/share/pixmaps/pccard-network.png"},
 	{"gpe-aerial", PREFIX "/share/pixmaps/gpe-aerial.png"},
 	{NULL}
 };
 
+const char *dhcpcommands[] = {
+	"/sbin/dhcpcd %s &",
+	"/sbin/dhclient %s &",
+	"/sbin/udhcpc -i %s &",
+	"/usr/sbin/dhcpcd %s &",
+	"/usr/sbin/udhcpc -i %s &",
+	NULL
+};
+
 enum
 {
 	COL_ICON,
@@ -84,7 +93,7 @@ static GtkWidget *icon;
 static pid_t scanner_pid;
 static int sock;
 static psconfig_t cfg = { 0, "eth0", DT_ORINOCO, 40000, 0 ,0, FALSE,
-		"/tmp/spotkoord.txt", "/tmp/psdump.pcap", FALSE};
+		"/tmp/spotkoord.txt", "/tmp/psdump.pcap", FALSE, 0};
 static netinfo_t **netlist = NULL;
 static int netcount = 0;
 static guint timeout_id = 0;
@@ -99,6 +108,7 @@ GtkWidget *devices_window;
 gboolean radio_is_on = FALSE;
 GdkWindow *dock_window;
 static GSList *devices = NULL;
+GtkWidget *window;
 
 
 /* some forwards */
@@ -118,6 +128,42 @@ static GtkTreeStore *store;
 static GtkWidget *tree;
 static GtkCellRenderer *renderer;
 
+static void
+image_set(int size)
+{
+	GdkBitmap *bitmap;
+	GdkPixbuf *sbuf, *dbuf;
+	
+	if (size == 0)
+	{
+		GdkPixbuf *pbuf = gtk_image_get_pixbuf(GTK_IMAGE(icon));
+		size = gdk_pixbuf_get_width(pbuf);
+	}
+    sbuf = gpe_find_icon(radio_is_on ? "scan-on" : "scan-off");
+    dbuf = gdk_pixbuf_scale_simple(sbuf, size, size, GDK_INTERP_HYPER);
+    gdk_pixbuf_render_pixmap_and_mask (dbuf, NULL, &bitmap, 128);
+    gtk_widget_shape_combine_mask (GTK_WIDGET(window), NULL, 1, 0);
+    gtk_widget_shape_combine_mask (GTK_WIDGET(window), bitmap, 1, 0);
+    gdk_bitmap_unref (bitmap);
+    gtk_image_set_from_pixbuf(GTK_IMAGE(icon), dbuf);
+}
+
+/* find a valid dhcp command */
+static int
+check_dhcp(void)
+{
+	int i = 0;
+	char cmd[50];
+	
+	while (dhcpcommands[i])
+	{
+		sscanf(dhcpcommands[i], "%50s", cmd);
+		if (!access(cmd, F_OK))
+			return i;
+		i++;		
+	}	
+	return 0;	
+}
 
 /* send command to turn off device */
 static void
@@ -141,13 +187,13 @@ draw_signal (int signal)
 	rect.width = xsize;
 	rect.height = ysize;
 	gc = gdk_gc_new (GDK_DRAWABLE (dock_window));
-	gdk_gc_set_fill (gc, GDK_OPAQUE_STIPPLED);
+	gdk_gc_set_fill (gc, GDK_SOLID);
 	gdk_gc_set_rgb_fg_color (gc, &sigc);
 
 	gdk_window_invalidate_rect (dock_window, &rect, TRUE);
 	gdk_window_process_updates (dock_window, TRUE);
 	gdk_draw_rectangle (GDK_DRAWABLE (dock_window), gc, TRUE, 0,
-			    (xsize + 2) - signal * (ysize*2) / 255, ysize,
+			    (xsize + 2) - signal * (ysize*2) / 255, 4,
 			    signal * (ysize*2) / 255 + 2);
 	g_object_unref(G_OBJECT(gc));
 }
@@ -388,7 +434,7 @@ show_networks (void)
 	if (devices_window == NULL)
 	{
 		devices_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-
+		gtk_window_set_default_size(GTK_WINDOW(devices_window), 240, 310);
 		gtk_window_set_title (GTK_WINDOW (devices_window),
 				      _("Wireless networks"));
 		gpe_set_window_icon (devices_window, "gpe-aerial");
@@ -487,19 +533,12 @@ do_stop_radio (void)
 static void
 radio_off (void)
 {
-/*	if (timeout_id) 
-	{
-		gtk_timeout_remove(timeout_id);
-		timeout_id = 0;
-	}
-*/ gtk_widget_hide (menu_radio_off);
+	gtk_widget_hide (menu_radio_off);
 	gtk_widget_show (menu_radio_on);
 
-	gtk_image_set_from_pixbuf (GTK_IMAGE (icon),
-				   gpe_find_icon ("scan-off"));
-
 	do_stop_radio ();
-
+	image_set(0);
+	
 	draw_signal (0);
 }
 
@@ -802,13 +841,13 @@ radio_on (void)
 {
 	sigset_t sigs;
 	struct sockaddr_un name;
-
+	
 	gtk_widget_hide (menu_radio_on);
 	gtk_widget_show (menu_radio_off);
-
-	gtk_image_set_from_pixbuf (GTK_IMAGE (icon),
-				   gpe_find_icon ("scan-on"));
+	
 	radio_is_on = TRUE;
+	image_set(0);
+	
 	sigemptyset (&sigs);
 	sigaddset (&sigs, SIGCHLD);
 	/* start and connect to scanner */
@@ -846,6 +885,7 @@ radio_on (void)
 		usleep(200000);
 		get_networks();
 	}
+	cfg.dhcpcommand = check_dhcp();
 	cfg_changed = FALSE;
 	cfg.scan = TRUE;
 	send_config ();
@@ -927,22 +967,12 @@ aerial_shutdown ()
 gboolean 
 external_event(GtkWindow *window, GdkEventConfigure *event, gpointer user_data)
 {
-  GdkBitmap *bitmap;
-  GdkPixbuf *sbuf, *dbuf;
   int size;
 	
   if (event->type == GDK_CONFIGURE)
   {
     size = (event->width > event->height) ? event->height : event->width;
-    sbuf = gpe_find_icon(radio_is_on ? "scan-on" : "scan-off");
-    dbuf = gdk_pixbuf_scale_simple(sbuf,size, size,GDK_INTERP_HYPER);
-    gdk_pixbuf_render_pixmap_and_mask (dbuf, NULL, &bitmap, 128);
-    gtk_widget_shape_combine_mask (GTK_WIDGET(window), NULL, 0, 0);
-    gtk_widget_shape_combine_mask (GTK_WIDGET(window), bitmap, 0, 0);
-    gdk_bitmap_unref (bitmap);
-    gtk_image_set_from_pixbuf(GTK_IMAGE(icon),dbuf);
-	/* make sure we want to resize all the time */
-	gtk_widget_set_size_request(GTK_WIDGET(window),size+1,size);
+	image_set(size);
   }
   return FALSE;
 }
@@ -952,7 +982,6 @@ int
 main (int argc, char *argv[])
 {
 	Display *dpy;
-	GtkWidget *window;
 	GdkBitmap *bitmap;
 	GtkWidget *menu_remove;
 	GtkWidget *menu_off;
@@ -991,9 +1020,8 @@ main (int argc, char *argv[])
 				    G_TYPE_STRING);
 
 	window = gtk_plug_new (0);
-	gtk_widget_set_usize (window, 16, 16);
-	/* this makes it scale up to 48pixels child size if possible */	
-	gtk_widget_set_size_request(window,50,50);
+	gtk_window_set_resizable(GTK_WINDOW(window),TRUE);
+
 	gtk_widget_realize (window);
 
 	gtk_window_set_title (GTK_WINDOW (window), _("Wireless LAN control"));
@@ -1044,7 +1072,7 @@ main (int argc, char *argv[])
 	gtk_widget_show (icon);
 	gtk_misc_set_alignment(GTK_MISC(icon),0.0,0.5);
 	gdk_pixbuf_render_pixmap_and_mask (gpe_find_icon ("scan-off"), NULL,
-					   &bitmap, 128);
+					   &bitmap, 255);
 	
 	gtk_widget_shape_combine_mask (window, bitmap, 0, 0);
 	gdk_bitmap_unref (bitmap);
